<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2007 Georg Ringer <typo3 et ringer dot org>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * Plugin 'Tab Content' for the 'rgtabs' extension.
 *
 * @author	Georg Ringer <typo3 et ringer dot org>
 */


require_once(PATH_tslib.'class.tslib_pibase.php');

class tx_rgtabs_pi1 extends tslib_pibase {
	var $prefixId = 'tx_rgtabs_pi1';		// Same as class name
	var $scriptRelPath = 'pi1/class.tx_rgtabs_pi1.php';	// Path to this script relative to the extension dir.
	var $extKey = 'rgtabs';	// The extension key.

	/**
	 * Just a initalization for the plugin
	 *
	 * @param	array		$conf: The PlugIn configuration
	 * @return	just some configs
	 */
	function init($conf) {
		$this->pi_loadLL(); // Loading language-labels
		$this->pi_setPiVarDefaults(); // Set default piVars from TS
		$this->pi_initPIflexForm(); // Init FlexForm configuration for plugin
		
		$this->templateCode = $this->cObj->fileResource($conf['templateFile']);
		$this->config['content'] = $this->pi_getFFvalue($this->cObj->data['pi_flexform'], 'content', 'sDEF');
	}
  	
	/**
	 * The main method of the PlugIn
	 *
	 * @param	string		$content: The PlugIn content
	 * @param	array		$conf: The PlugIn configuration
	 * @return	The content that is displayed on the website
	 */
	function main($content,$conf)	{
		$this->init($conf);
		$this->conf=$conf;
		$this->pi_setPiVarDefaults();
		$this->pi_loadLL();
		$this->pi_USER_INT_obj=1;	// Configuring so caching is not expected. This value means that no cHash params are ever set. We do this, because it's a USER_INT object!

    // If a CE is selected, call function getTabs, else do nothing
    if ($this->config['content'] != '') return $this->pi_wrapInBaseClass($this->getTabs($conf));
    else return '';
	}

	/**
	 * xajax function to insert CE in the resultdiv
	 *
	 * @param	int		$uid: UID of the element
	 * @return	The content element
	 */	
  function singleTab($uid)	{
    $uid = intval($uid);
  
    // render the CE
    $conf = array('tables' => 'tt_content','source' => $uid,'dontCheckPid' => 1);
		$content = $this->cObj->RECORDS($conf);
		
    // make the prev/next link
    $content = $this->prevNextLink($content, $uid);

		$objResponse = new tx_xajax_response();
		$objResponse->addAssign('rgtabs-content', 'innerHTML', $content);
		return $objResponse->getXML();
	} 

	/**
	 * creates the links for prev & next tab
	 *
	 * @param	string		$ce: the content element
	 * @param	int		$uid: id of current content element
	 * @return	The content element + links
	 */		
	function prevNextLink($ce,$uid) {
    // List of CEs
    $uidList = explode(',',$this->config['content']);
    $currentPos = array_search($uid,$uidList);
    
    // if links should be shown
    if ($this->conf['showLinks'] == 1) {
      
      // link to previous CE
      if ($currentPos > 0) {
        $onClick = ' onClick=\'  ' . $this->prefixId . 'getElement('.$uidList{$currentPos-1}.');  \'  ';
        if ($this->conf['prevLink.']['override.']) {
          $title = 'previous';        
        } else {
          $title = $this->getTitle($uidList{$currentPos-1});
        }
        $text = $this->cObj->stdWrap($title,$this->conf['prevLink.']);
        $links.= $this->cObj->stdWrap('<a '.$onClick.' >'.$text.'</a>',$this->conf['prevWrap.']);
      }
      // link to next CE
      if ($currentPos < (count($uidList)-1)) {
        $onClick = ' onClick=\'  ' . $this->prefixId . 'getElement('.$uidList{$currentPos+1}.');  \'  ';
 
        if ($this->conf['nextLink.']['override.']) {
          $title = 'next';        
        } else {
          $title = $this->getTitle($uidList{$currentPos+1});
        }
        $text = $this->cObj->stdWrap($title,$this->conf['nextLink.']);
        $links.= $this->cObj->stdWrap('<a '.$onClick.' >'.$text.'</a>',$this->conf['nextWrap.']);
      }  
      
      $content = ($this->conf['topOrBottom']!= 'top') ? $ce.$links : $links.$ce;
    // no links set
    } else {
      $content = $ce;
    }
    
    return $content; 
  }

	/**
	 * get the title of the neighbour content elements for prev/next likn
	 *
	 * @param	int		$uid: id of one neighbour content element
	 * @return	The header of the tt_content element
	 */	  
  function getTitle ($uid) {
		global $TYPO3_DB;
    $table = 'tt_content';
    $where = 'uid ='.$uid;
    $fields = 'header';
    $res = $TYPO3_DB->exec_SELECTquery($fields,$table,$where,$groupBy,$orderBy,$limit);
		$row = $TYPO3_DB->sql_fetch_assoc($res);		
		return $row['header'];
  }

	/**
	 * xajax function which returns the Menu
	 *
	 * @param	int		$uid: id of one neighbour content element
	 * @return	The header of the tt_content element
	 */  
  function getMenu($uid=0) {
    // call the "real" menu function
    $content = $this->getMenu2($uid);

    // Instantiate the tx_xajax_response object
    $objResponse = new tx_xajax_response();
		$objResponse->addAssign('rgtabs-menu', 'innerHTML', $content);  
    return $objResponse->getXML();
  }

	/**
	 * Creation of the menu
	 *
	 * @param	int		$uid: id of the current element to highlight selected ce
	 * @return	The menu
	 */  
  function getMenu2 ($uid) {
		global $TYPO3_DB;
    // Query
    $table = 'tt_content';
    $where = 'uid IN ('.$this->config['content'].') AND deleted = 0 AND hidden = 0';
    $fields = 'uid, header';
    $res = $TYPO3_DB->exec_SELECTquery($fields,$table,$where,$groupBy,$orderBy,$limit);

    // generating list
    $tabs = Array();
    
    // List of IDs in an Array
    $uidList = explode(',',$this->config['content']);
    
		while($row = $TYPO3_DB->sql_fetch_assoc($res)) {
		  // remember the first element
      if ($row['uid'] ==$uidList{0}) {
        $uidFirstElement = $row['uid'];
      }
      $selected = ($row['uid'] == $uid) ? 'class="selected" ' : '';
      $onClick = ' onClick=\'  ' . $this->prefixId . 'getMenu('.$row['uid'].'); ' . $this->prefixId . 'singleTab('.$row['uid'].'); \'  '; 
     $onClick = ' onClick=\'  ' . $this->prefixId . 'getElement('.$row['uid'].');  \'  '; 
     $title = $this->cObj->stdWrap($row['header'],$this->conf['header.'][$row['uid'].'.']);
      $tabs[$row['uid']] = '<li '.$selected.'><a '.$onClick.'>'.$title.'</a></li>';
		}
		
		// render the first element
		$conf = array('tables' => 'tt_content','source' => $uidFirstElement,'dontCheckPid' => 1);
		$ce = $this->cObj->RECORDS($conf);
    $markerArray['###FIRST_ELEMENT###'] = $this->prevNextLink($ce,$uidFirstElement);
    
    //output of the menu
		$menu = '<ul class="rgtabs-tab">';
    foreach ($uidList as $key=>$value) {
      $menu .= $tabs[$value];
    }
    $menu = $menu.'</ul>';  
    
    return $menu; 
  }

	/**
	 * The really main function, does everything
   *   
 	 * @param	array		$conf: The PlugIn configuration
	 * @return	The whole tab menu
	 */   	
	function getTabs ($conf) {
		global $TYPO3_DB, $TSFE;
		$this->conf=$conf;
		$this->pi_setPiVarDefaults();
		$this->pi_loadLL();

		// xajax code
    require (t3lib_extMgm::extPath('xajax') . 'class.tx_xajax.php');
		
		$this->xajax = t3lib_div::makeInstance('tx_xajax'); // Make the instance
		if ($TSFE->renderCharset == 'utf-8') $this->xajax->decodeUTF8InputOn(); 		// Decode form vars from utf8 ???
		$this->xajax->setCharEncoding($TSFE->renderCharset); 		// Encode of the response to utf-8 ???
		$this->xajax->setWrapperPrefix($this->prefixId); 		// To prevent conflicts, prepend the extension prefix
		#$this->xajax->statusMessagesOn(); 		// Do you wnat messages in the status bar?
		#$this->xajax->debugOn();
		$this->xajax->registerFunction(array('singleTab', &$this, 'singleTab'));
		$this->xajax->registerFunction(array('getMenu', &$this, 'getMenu'));		
  	$this->xajax->processRequests(); 		// Else create javascript and add it to the header output
		$GLOBALS['TSFE']->additionalHeaderData[$this->prefixId] = $this->xajax->getJavascript(t3lib_extMgm::siteRelPath('xajax'));  

    // Addidional javascript, needed for text w image + ajax functions
    $GLOBALS['TSFE']->additionalHeaderData['131212'] = '<script type="text/javascript" src="'.t3lib_extMgm::siteRelpath('rgtabs').'/res/rgtabs.js"></script>';    

    // Template
    $template["list"] = $this->cObj->getSubpart($this->templateCode,"###TEMPLATE###");
    
    // render the first element
    $uidList = explode(',',$this->config['content']);
		$conf = array('tables' => 'tt_content','source' => $uidList{0},'dontCheckPid' => 1);
		$ce = $this->cObj->RECORDS($conf);
    $markerArray['###FIRST_ELEMENT###'] = $this->prevNextLink($ce,$uidFirstElement);
    
    // get the menu
    $markerArray['###MENU###'] = $this->getMenu2($uidList{0});
    
    $content.= $this->cObj->substituteMarkerArrayCached($template["list"],$markerArray, $subpartArray,$wrappedSubpartArray);  
    return $content;
  }
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rgtabs/pi1/class.tx_rgtabs_pi1.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rgtabs/pi1/class.tx_rgtabs_pi1.php']);
}

?>
